import { Action, getModule, Module, Mutation, MutationAction, VuexModule } from 'vuex-module-decorators';
import store from '@/store';
import http from '@/utils/request';
import { url } from '@/utils/url';
import { session } from '@/store/modules/session';

class OrderInInfo {
  checked?: boolean;
  dnNo?: string;
  kw?: string;
  userDefined10?: string;
  orderStatus?: string;
  // carNo?: string;
  // bookingTime?: string;
  supplyCode?: string;
  poType?: string;
  location?: string;
}

@Module({
  namespaced: true,
  dynamic: true,
  store,
  name: 'raw.ingoods.dnReturnGoods',
})
export class ReceiptModule extends VuexModule {
  /**
   * sap库存地点列表
   */
  cboPlaceList = [];
  /**
   * 隐藏看单号
   */
  dnNo = '';
  dnReturnList = [];
  code: any = '';
  // 容器码
  ContainerCode: any = '';
  /**
   * 看单号查询结果
   */
  orderInInfo: OrderInInfo = new OrderInInfo();
  detailedList = [];
  /**
   * 看单明细
   */
  orderInInfoList: OrderInInfo[] = [];
  /**
   * 看单明细未通过明细
   */
  orderInInfoListEx: OrderInInfo[] = [];

  /**
   * 是否已查询看单号
   */
  get hasDnInfo() {
    return !!this.orderInInfo.dnNo;
  }

  /**
   * 是否全选
   */
  get isCheckedAll() {
    return !this.orderInInfoList.filter((_) => !_.checked).length;
  }

  /**
   * 是否有选择项
   */
  get hasChecked() {
    return this.orderInInfoList.filter((_) => _.checked).length > 0;
  }

  /**
   * 更新看单明细库位
   * @param kw 库位
   */
  @Mutation
  updateOrderInInfoListKw(kw: string) {
    this.orderInInfoList = this.orderInInfoList.map((item) => {
      item.kw = kw;
      return item;
    });
  }

  /**
   * 更新选中的看单明细库位
   * @param kw 库位
   */
  @Mutation
  updateCheckedOrderInInfoListKw(kw: string) {
    this.orderInInfoList = this.orderInInfoList.map((item) => {
      if (item.checked) {
        item.kw = kw;
      }
      return item;
    });
  }

  /**
   * 看单明细全选/全不选
   */
  @Mutation
  checkAllOrderInInfoList(checked: boolean) {
    this.orderInInfoList = this.orderInInfoList.map((item) => {
      item.checked = checked;
      return item;
    });
  }

  /**
   * 查询库位列表
   */
  @MutationAction
  async queryLocation() {
    const result: any = await http.post(url.auth.query.location, {
      factoryCode: session.factoryCode,
      loginName: session.loginName,
      workareaCode: session.workareaCode,
    });
    const cboPlaceList = result.list.map((_: any) => ({
      label: _.locationCode,
      value: _.locationCode,
    }));
    return { cboPlaceList };
  }

  /**
   * 查询单号
   * 查询DN单号
   * @param dnNo
   */
  @MutationAction
  async queryOrderInInfo(dnNo: string) {
    const { list }: any = await http.post(url.material.DNorderin.dnReturnInfo, {
      dnNo,
      factoryCode: session.factoryCode,
      loginName: session.loginName,
    });
    const orderInInfo = list[0] || {};
    const orderInInfoList = list.filter((_: OrderInInfo) => _.userDefined10 === '1');
    const orderInInfoListEx = list.filter((_: OrderInInfo) => _.userDefined10 === '0');
    orderInInfoList.forEach((item: any) => {
      item.returnAmount = item.requestAmount;
    });
    console.log('1111111', orderInInfoList);
    return { dnNo, orderInInfo, orderInInfoList, orderInInfoListEx };
  }
  @MutationAction
  async queryOrder(poNo: string) {
    const res: any = await http.post(url.material.DNorderin.queryOrder, {
      poNo,
      factoryCode: session.factoryCode,
      loginName: session.loginName,
    });
    const orderInInfoListEx = res.data.filter((_: OrderInInfo) => _.userDefined10 === '0');
    const dnReturnList = res.data;
    dnReturnList.forEach((item: any) => {
      item.list = [];
    });
    const orderInInfo: any = res.data[0] || {};
    const code = res.code;
    console.log('orderInInfo', orderInInfo);
    return { orderInInfo, orderInInfoListEx, dnReturnList, code };
  }
  /**
   * 提交看单明细
   */
  @MutationAction
  async submitOrderInEnter() {
    // const list = (this.state as any).orderInInfoList.map((item: any) => {
    //   item.orderStatus = item.checked ? '2' : '1';
    //   item.requestAmount = item.checked ? item.y : '0';
    //   return item;
    // });
    const list = (this.state as any).orderInInfoList;
    const result: any = await http.post(url.material.DNorderin.out, {
      dnNo: this.dnNo,
      factoryCode: session.factoryCode,
      loginName: session.loginName,
      list,
    });
    uni.showToast({
      icon: 'none',
      title: result.msg,
    });
    const orderInInfoList = result.list.sort((a: any, b: any) => Number(a.accountingStatus) - Number(b.accountingStatus));
    return { orderInInfoList };
  }

  /**
   * 修改库位
   */
  @Action({ commit: 'updateCheckedOrderInInfoListKw' })
  async changeOrderInLocation(kw: string) {
    await http.post('/wmspda/material/orderin/enter', {
      warehouseCode: session.warehouseCode,
      factoryCode: session.factoryCode,
      loginName: session.loginName,
      locationCode: kw,
    });
    return kw;
  }

  @Action({ commit: 'updateCheckedOrderInInfoListKw' })
  async queryByFactoryCodeAndWorkAreaCode(content: any) {
    const res = await http.post('/wmspda/fg/queryByFactoryCodeAndWorkAreaCode', content);
    return res;
  }
  @Action({ commit: 'updateCheckedOrderInInfoListKw' })
  async queryByFactory(content: any) {
    const res = await http.post('/wmspda/fg/queryByFactoryCodeAndWorkAreaCode', content);
    return res;
  }
  @MutationAction
  async submit(content: any) {
    const res: any = await http.post('/wmspda/material/poReturn/materialCompleteTwo', content);
    const code = res.code;
    return { code };
  }
  @MutationAction
  async querydetaildlist(content: any) {
    const res = await http.post('/wmspda/material/poReturn/info', content);
    const detailedList = res.data;
    return { detailedList };
  }
  //俄罗斯扫描容器码
  @MutationAction
  async searchBarcode(params: any) {
    const res: any = await http.post(url.auth.query.barcode, {
      factoryCode: session.factoryCode,
      loginName: session.loginName,
      barcode: params.barcode,
      productCode: params.productCode,
    });
    const ContainerCode = res.data;
    return { ContainerCode };
  }
}

export default getModule(ReceiptModule);
